@@ -1,6 +1,9 @@
+#pragma once
+
 #include <ATen/core/alias_info.h>
 
-namespace torch { namespace jit {
+namespace torch {
+namespace jit {
 
 using ::c10::AliasInfo;
 
