@@ -4,11 +4,6 @@ import torch
 import torch.nn.functional as F
 
 
-# promote numbers to tensors of dtype torch.get_default_dtype()
-def _default_promotion(v):
-    return torch.tensor(v, dtype=torch.get_default_dtype())
-
-
 def broadcast_all(*values):
     r"""
     Given a list of values (possibly containing numbers), returns a list where each
@@ -28,12 +23,13 @@ def broadcast_all(*values):
     if not all(torch.is_tensor(v) or isinstance(v, Number) for v in values):
         raise ValueError('Input arguments must all be instances of numbers.Number or torch.tensor.')
     if not all(map(torch.is_tensor, values)):
-        new_tensor = _default_promotion
+        options = dict(dtype=torch.get_default_dtype())
         for value in values:
             if torch.is_tensor(value):
-                new_tensor = value.new_tensor
+                options = dict(dtype=value.dtype, device=value.device)
                 break
-        values = [v if torch.is_tensor(v) else new_tensor(v) for v in values]
+        values = [v if torch.is_tensor(v) else torch.tensor(v, **options)
+                  for v in values]
     return torch.broadcast_tensors(*values)
 
 
