@@ -42,7 +42,7 @@ if sys.version_info < (3, 3):
 
 """Add helper function to spawn N processes and wait for completion of any of
 them. This depends `mp.get_context` which was added in Python 3.4."""
-from .spawn import spawn, SpawnContext  # noqa: F401
+from .spawn import spawn, SpawnContext, _supports_context  # noqa: F401
 
 
 if sys.platform == 'darwin' or sys.platform == 'win32':
